"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.register = void 0;
function register({ modules: { typescript: ts }, getVueDocument }) {
    return (document, position) => {
        const soureFile = getVueDocument(document);
        if (!soureFile)
            return;
        const templateFormatScript = soureFile.getTemplateFormattingScript();
        if (!templateFormatScript.document || !templateFormatScript.sourceMap)
            return;
        const offset = document.offsetAt(position);
        for (const mapedRange of templateFormatScript.sourceMap.mappings) {
            if (mapedRange.sourceRange.end === offset) {
                const text = document.getText().substring(mapedRange.sourceRange.start, mapedRange.sourceRange.end);
                const ast = ts.createSourceFile(templateFormatScript.document.uri, text, ts.ScriptTarget.Latest);
                if (ast.statements.length === 1) {
                    const statement = ast.statements[0];
                    if (ts.isExpressionStatement(statement)
                        && ts.isAsExpression(statement.expression)
                        && ts.isTypeReferenceNode(statement.expression.type)
                        && ts.isIdentifier(statement.expression.type.typeName)
                        && statement.expression.type.typeName.text) {
                        return {
                            text: '(' + text + '$0' + ')',
                            range: {
                                start: document.positionAt(mapedRange.sourceRange.start),
                                end: document.positionAt(mapedRange.sourceRange.end),
                            },
                        };
                    }
                }
            }
        }
    };
}
exports.register = register;
//# sourceMappingURL=autoWrapParentheses.js.map